@@ -326,6 +326,8 @@ def protontricks(verb: str) -> bool:
         winetricks_cmd = [winetricks_bin, '--unattended'] + verb.split(' ')
         if verb == 'gui':
             winetricks_cmd = [winetricks_bin, '--unattended']
+        if 'dotnet' in verb:
+            env['PROTON_USE_XALIA'] = '0'
 
         # check is verb a custom winetricks verb
         custom_verb = is_custom_verb(verb)
@@ -364,6 +366,9 @@ def protontricks(verb: str) -> bool:
             log.info('Winetricks complete')
             return True
 
+        if 'dotnet' in verb:
+            env['PROTON_USE_XALIA'] = '1'
+
     return False
 
 
@@ -1203,13 +1208,14 @@ def get_steam_account_id() -> Optional[str]:
 
 
 def create_dos_device(
-    letter: str = 'r', dev_type: DosDevice = DosDevice.CD_ROM
+    letter: str = 'r', dev_type: DosDevice = DosDevice.CD_ROM, path: str = '/tmp'
 ) -> bool:
-    """Create a symlink to '/tmp' in the dosdevices folder of the prefix and register it
+    """Create a symlink to <path> in the dosdevices folder of the prefix and register it
 
     Args:
         letter (str, optional): Letter that the device gets assigned to, must be len = 1
         dev_type (DosDevice, optional): The device's type which will be registered to wine
+        path (str, optional): The link target path, defaults to `/tmp`
 
     Returns:
         bool: True, if device was created
@@ -1222,7 +1228,7 @@ def create_dos_device(
         return False
 
     # Create a symlink in dosdevices
-    dosdevice.symlink_to('/tmp', True)
+    dosdevice.symlink_to(path, True)
 
     # designate device as CD-ROM, requires 64-bit access
     regedit_add(
